@@ -920,18 +920,34 @@ pub fn is_extended_transient_error(err: &dyn Error) -> bool {
     }
 
     // IO Errors may be nested through custom IO errors.
+    let mut has_io_error = false;
     for io_err in find_sources::<io::Error>(&err) {
-        if io_err.kind() == io::ErrorKind::ConnectionReset
-            || io_err.kind() == io::ErrorKind::UnexpectedEof
-            || io_err.kind() == io::ErrorKind::BrokenPipe
-        {
-            trace!("Retrying error: `ConnectionReset` or `UnexpectedEof`");
+        has_io_error = true;
+        let retryable_io_err_kinds = [
+            // https://github.com/astral-sh/uv/issues/12054
+            io::ErrorKind::BrokenPipe,
+            // From reqwest-middleware
+            io::ErrorKind::ConnectionAborted,
+            // https://github.com/astral-sh/uv/issues/3514
+            io::ErrorKind::ConnectionReset,
+            // https://github.com/astral-sh/uv/issues/14699
+            io::ErrorKind::InvalidData,
+            // https://github.com/astral-sh/uv/issues/9246
+            io::ErrorKind::UnexpectedEof,
+        ];
+        if retryable_io_err_kinds.contains(&io_err.kind()) {
+            trace!("Retrying error: `{}`", io_err.kind());
             return true;
         }
-        trace!("Cannot retry IO error: not one of `ConnectionReset` or `UnexpectedEof`");
+        trace!(
+            "Cannot retry IO error `{}`, not a retryable IO error kind",
+            io_err.kind()
+        );
     }
 
-    trace!("Cannot retry error: not an IO error");
+    if !has_io_error {
+        trace!("Cannot retry error: not an extended IO error");
+    }
     false
 }
 
