@@ -97,7 +97,8 @@ pub(crate) fn create(
                 }
                 OnExisting::Remove => {
                     debug!("Removing existing {name} due to `--clear`");
-                    remove_venv_directory(location)?;
+                    remove_virtualenv(location)?;
+                    fs::create_dir_all(location)?;
                 }
                 OnExisting::Fail
                     if location
@@ -110,7 +111,8 @@ pub(crate) fn create(
                     match confirm_clear(location, name)? {
                         Some(true) => {
                             debug!("Removing existing {name} due to confirmation");
-                            remove_venv_directory(location)?;
+                            remove_virtualenv(location)?;
+                            fs::create_dir_all(location)?;
                         }
                         Some(false) => {
                             let hint = format!(
@@ -242,6 +244,16 @@ pub(crate) fn create(
                 interpreter.python_minor(),
             )),
         )?;
+        if interpreter.gil_disabled() {
+            uv_fs::replace_symlink(
+                "python",
+                scripts.join(format!(
+                    "python{}.{}t",
+                    interpreter.python_major(),
+                    interpreter.python_minor(),
+                )),
+            )?;
+        }
 
         if interpreter.markers().implementation_name() == "pypy" {
             uv_fs::replace_symlink(
@@ -262,12 +274,21 @@ pub(crate) fn create(
     if cfg!(windows) {
         if using_minor_version_link {
             let target = scripts.join(WindowsExecutable::Python.exe(interpreter));
-            create_link_to_executable(target.as_path(), executable_target.clone())
+            create_link_to_executable(target.as_path(), &executable_target)
                 .map_err(Error::Python)?;
             let targetw = scripts.join(WindowsExecutable::Pythonw.exe(interpreter));
-            create_link_to_executable(targetw.as_path(), executable_target)
+            create_link_to_executable(targetw.as_path(), &executable_target)
                 .map_err(Error::Python)?;
+            if interpreter.gil_disabled() {
+                let targett = scripts.join(WindowsExecutable::PythonMajorMinort.exe(interpreter));
+                create_link_to_executable(targett.as_path(), &executable_target)
+                    .map_err(Error::Python)?;
+                let targetwt = scripts.join(WindowsExecutable::PythonwMajorMinort.exe(interpreter));
+                create_link_to_executable(targetwt.as_path(), &executable_target)
+                    .map_err(Error::Python)?;
+            }
         } else {
+            // Always copy `python.exe`.
             copy_launcher_windows(
                 WindowsExecutable::Python,
                 interpreter,
@@ -276,81 +297,111 @@ pub(crate) fn create(
                 python_home,
             )?;
 
-            if interpreter.markers().implementation_name() == "graalpy" {
-                copy_launcher_windows(
-                    WindowsExecutable::GraalPy,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PythonMajor,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-            } else {
-                copy_launcher_windows(
-                    WindowsExecutable::Pythonw,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-            }
+            match interpreter.implementation_name() {
+                "graalpy" => {
+                    // For GraalPy, copy `graalpy.exe` and `python3.exe`.
+                    copy_launcher_windows(
+                        WindowsExecutable::GraalPy,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PythonMajor,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                }
+                "pypy" => {
+                    // For PyPy, copy all versioned executables and all PyPy-specific executables.
+                    copy_launcher_windows(
+                        WindowsExecutable::PythonMajor,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PythonMajorMinor,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::Pythonw,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PyPy,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PyPyMajor,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PyPyMajorMinor,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PyPyw,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                    copy_launcher_windows(
+                        WindowsExecutable::PyPyMajorMinorw,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
+                }
+                _ => {
+                    // For all other interpreters, copy `pythonw.exe`.
+                    copy_launcher_windows(
+                        WindowsExecutable::Pythonw,
+                        interpreter,
+                        &base_python,
+                        &scripts,
+                        python_home,
+                    )?;
 
-            if interpreter.markers().implementation_name() == "pypy" {
-                copy_launcher_windows(
-                    WindowsExecutable::PythonMajor,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PythonMajorMinor,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PyPy,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PyPyMajor,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PyPyMajorMinor,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PyPyw,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
-                copy_launcher_windows(
-                    WindowsExecutable::PyPyMajorMinorw,
-                    interpreter,
-                    &base_python,
-                    &scripts,
-                    python_home,
-                )?;
+                    // If the GIL is disabled, copy `venvlaunchert.exe` and `venvwlaunchert.exe`.
+                    if interpreter.gil_disabled() {
+                        copy_launcher_windows(
+                            WindowsExecutable::PythonMajorMinort,
+                            interpreter,
+                            &base_python,
+                            &scripts,
+                            python_home,
+                        )?;
+                        copy_launcher_windows(
+                            WindowsExecutable::PythonwMajorMinort,
+                            interpreter,
+                            &base_python,
+                            &scripts,
+                            python_home,
+                        )?;
+                    }
+                }
             }
         }
     }
@@ -517,9 +568,10 @@ fn confirm_clear(location: &Path, name: &'static str) -> Result<Option<bool>, io
     }
 }
 
-fn remove_venv_directory(location: &Path) -> Result<(), Error> {
-    // On Windows, if the current executable is in the directory, guard against
-    // self-deletion.
+/// Perform a safe removal of a virtual environment.
+pub fn remove_virtualenv(location: &Path) -> Result<(), Error> {
+    // On Windows, if the current executable is in the directory, defer self-deletion since Windows
+    // won't let you unlink a running executable.
     #[cfg(windows)]
     if let Ok(itself) = std::env::current_exe() {
         let target = std::path::absolute(location)?;
@@ -529,8 +581,27 @@ fn remove_venv_directory(location: &Path) -> Result<(), Error> {
         }
     }
 
+    // We defer removal of the `pyvenv.cfg` until the end, so if we fail to remove the environment,
+    // uv can still identify it as a Python virtual environment that can be deleted.
+    for entry in fs::read_dir(location)? {
+        let entry = entry?;
+        let path = entry.path();
+        if path == location.join("pyvenv.cfg") {
+            continue;
+        }
+        if path.is_dir() {
+            fs::remove_dir_all(&path)?;
+        } else {
+            fs::remove_file(&path)?;
+        }
+    }
+
+    match fs::remove_file(location.join("pyvenv.cfg")) {
+        Ok(()) => {}
+        Err(err) if err.kind() == io::ErrorKind::NotFound => {}
+        Err(err) => return Err(err.into()),
+    }
     fs::remove_dir_all(location)?;
-    fs::create_dir_all(location)?;
 
     Ok(())
 }
@@ -567,8 +638,12 @@ enum WindowsExecutable {
     PythonMajor,
     /// The `python3.<minor>.exe` executable (or `venvlauncher.exe` launcher shim).
     PythonMajorMinor,
+    /// The `python3.<minor>t.exe` executable (or `venvlaunchert.exe` launcher shim).
+    PythonMajorMinort,
     /// The `pythonw.exe` executable (or `venvwlauncher.exe` launcher shim).
     Pythonw,
+    /// The `pythonw3.<minor>t.exe` executable (or `venvwlaunchert.exe` launcher shim).
+    PythonwMajorMinort,
     /// The `pypy.exe` executable.
     PyPy,
     /// The `pypy3.exe` executable.
@@ -579,7 +654,7 @@ enum WindowsExecutable {
     PyPyw,
     /// The `pypy3.<minor>w.exe` executable.
     PyPyMajorMinorw,
-    // The `graalpy.exe` executable
+    /// The `graalpy.exe` executable.
     GraalPy,
 }
 
@@ -598,7 +673,21 @@ impl WindowsExecutable {
                     interpreter.python_minor()
                 )
             }
+            WindowsExecutable::PythonMajorMinort => {
+                format!(
+                    "python{}.{}t.exe",
+                    interpreter.python_major(),
+                    interpreter.python_minor()
+                )
+            }
             WindowsExecutable::Pythonw => String::from("pythonw.exe"),
+            WindowsExecutable::PythonwMajorMinort => {
+                format!(
+                    "pythonw{}.{}t.exe",
+                    interpreter.python_major(),
+                    interpreter.python_minor()
+                )
+            }
             WindowsExecutable::PyPy => String::from("pypy.exe"),
             WindowsExecutable::PyPyMajor => {
                 format!("pypy{}.exe", interpreter.python_major())
@@ -633,6 +722,8 @@ impl WindowsExecutable {
             Self::Python | Self::PythonMajor | Self::PythonMajorMinor => "venvlauncher.exe",
             Self::Pythonw if interpreter.gil_disabled() => "venvwlaunchert.exe",
             Self::Pythonw => "venvwlauncher.exe",
+            Self::PythonMajorMinort => "venvlaunchert.exe",
+            Self::PythonwMajorMinort => "venvwlaunchert.exe",
             // From 3.13 on these should replace the `python.exe` and `pythonw.exe` shims.
             // These are not relevant as of now for PyPy as it doesn't yet support Python 3.13.
             Self::PyPy | Self::PyPyMajor | Self::PyPyMajorMinor => "venvlauncher.exe",
