@@ -718,7 +718,7 @@ fn create_venv_warns_user_on_requires_python_discovery_error() -> Result<()> {
     let pyproject_toml = context.temp_dir.child("pyproject.toml");
     pyproject_toml.write_str(indoc! { r"invalid toml" })?;
 
-    uv_snapshot!(context.filters(), context.venv(), @r###"
+    uv_snapshot!(context.filters(), context.venv(), @r"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -729,19 +729,19 @@ fn create_venv_warns_user_on_requires_python_discovery_error() -> Result<()> {
         |
       1 | invalid toml
         |         ^
-      expected `.`, `=`
+      key with no value, expected `=`
 
     warning: Failed to parse `pyproject.toml` during environment creation:
       TOML parse error at line 1, column 9
         |
       1 | invalid toml
         |         ^
-      expected `.`, `=`
+      key with no value, expected `=`
 
     Using CPython 3.12.[X] interpreter at: [PYTHON-3.12]
     Creating virtual environment at: .venv
     Activate with: source .venv/[BIN]/activate
-    "###
+    "
     );
 
     context.venv.assert(predicates::path::is_dir());
